@@ -51,7 +51,7 @@
  */
 #undef Tcl_RegisterObjType
 #define Tcl_RegisterObjType(typePtr) if (threadTclVersion<90) { \
-    ((void (*)(const Tcl_ObjType *))((&(tclStubsPtr->tcl_PkgProvideEx))[211]))(typePtr); \
+    ((void (*)(const Tcl_ObjType *))(void *)((&(tclStubsPtr->tcl_PkgProvideEx))[211]))(typePtr); \
 } else { \
     (typePtr)->setFromAnyProc = NULL; \
 }
@@ -69,7 +69,7 @@
  */
 
 #ifdef TCLX_DEBUG
-# define TclX_Assert(expr) ((expr) ? (void)0 : \
+# define TclX_Assert(expr) ((expr) ? NULL : \
                             panic("TclX assertion failure: %s:%d \"%s\"\n",\
                             __FILE__, __LINE__, "expr"))
 #else
@@ -82,10 +82,10 @@
  */
 
 #define ckstrdup(sourceStr) \
-  (strcpy (ckalloc (strlen (sourceStr) + 1), sourceStr))
+  (strcpy ((char *)ckalloc (strlen (sourceStr) + 1), sourceStr))
 
 #define ckbinstrdup(sourceStr, length) \
-  ((char *) memcpy (ckalloc (length + 1), sourceStr, length + 1))
+  ((char *) memcpy ((char *)ckalloc (length + 1), sourceStr, length + 1))
 
 /*
  * Used to return argument messages by most commands.
@@ -107,9 +107,9 @@ static const Tcl_ObjType *listType;
  *-----------------------------------------------------------------------------
  */
 static int
-TclX_IsNullObj (objPtr)
-    Tcl_Obj *objPtr;
-{
+TclX_IsNullObj (
+    Tcl_Obj *objPtr
+) {
     if (objPtr->typePtr == NULL) {
         return (objPtr->length == 0);
     } else if (objPtr->typePtr == listType) {
@@ -144,7 +144,7 @@ TclX_AppendObjResult(Tcl_Interp *interp, ...)
     resultPtr = Tcl_GetObjResult (interp);
 
     if (Tcl_IsShared(resultPtr)) {
-        resultPtr = Tcl_NewStringObj((char *)NULL, 0);
+        resultPtr = Tcl_NewStringObj(NULL, 0);
         Tcl_SetObjResult(interp, resultPtr);
     }
 
@@ -171,11 +171,11 @@ TclX_AppendObjResult(Tcl_Interp *interp, ...)
  *-----------------------------------------------------------------------------
  */
 static int
-TclX_WrongArgs (interp, commandNameObj, string)
-    Tcl_Interp  *interp;
-    Tcl_Obj     *commandNameObj;
-    char        *string;
-{
+TclX_WrongArgs(
+    Tcl_Interp  *interp,
+    Tcl_Obj     *commandNameObj,
+    const char  *string
+) {
     const char *commandName = Tcl_GetString(commandNameObj);
     Tcl_Obj *resultPtr = Tcl_GetObjResult(interp);
 
@@ -183,10 +183,10 @@ TclX_WrongArgs (interp, commandNameObj, string)
     Tcl_AppendStringsToObj (resultPtr,
                             tclXWrongArgs,
                             commandName,
-                            (char *)NULL);
+                            NULL);
 
     if (*string != '\0') {
-        Tcl_AppendStringsToObj (resultPtr, " ", string, (char *)NULL);
+        Tcl_AppendStringsToObj (resultPtr, " ", string, NULL);
     }
     return TCL_ERROR;
 }
@@ -285,7 +285,7 @@ DeleteKeyedListEntry(keylIntObj_t *keylIntPtr,
 static int
 FindKeyedListEntry(keylIntObj_t *keylIntPtr,
                                 const char   *key,
-                                int          *keyLenPtr,
+                                size_t       *keyLenPtr,
                                 const char   **nextSubKeyPtr);
 
 static int
@@ -308,25 +308,25 @@ static void
 UpdateStringOfKeyedList(Tcl_Obj *keylPtr);
 
 static int
-Tcl_KeylgetObjCmd(ClientData   clientData,
+Tcl_KeylgetObjCmd(void        *clientData,
                                Tcl_Interp  *interp,
                                int          objc,
                                Tcl_Obj     *const objv[]);
 
 static int
-Tcl_KeylsetObjCmd(ClientData   clientData,
+Tcl_KeylsetObjCmd(void        *clientData,
                                Tcl_Interp  *interp,
                                int          objc,
                                Tcl_Obj     *const objv[]);
 
 static int
-Tcl_KeyldelObjCmd(ClientData   clientData,
+Tcl_KeyldelObjCmd(void        *clientData,
                                Tcl_Interp  *interp,
                                int          objc,
                                Tcl_Obj     *const objv[]);
 
 static int
-Tcl_KeylkeysObjCmd(ClientData   clientData,
+Tcl_KeylkeysObjCmd(void        *clientData,
                                 Tcl_Interp  *interp,
                                 int          objc,
                                  Tcl_Obj     *const objv[]);
@@ -391,12 +391,12 @@ ValidateKeyedList (keylIntPtr)
  *-----------------------------------------------------------------------------
  */
 static int
-ValidateKey(interp, key, keyLen, isPath)
-    Tcl_Interp *interp;
-    const char *key;
-    size_t keyLen;
-    int isPath;
-{
+ValidateKey(
+    Tcl_Interp *interp,
+    const char *key,
+    size_t keyLen,
+    int isPath
+) {
     const char *keyp;
 
     if (strlen(key) != keyLen) {
@@ -436,7 +436,7 @@ ValidateKey(interp, key, keyLen, isPath)
  *-----------------------------------------------------------------------------
  */
 static keylIntObj_t *
-AllocKeyedListIntRep ()
+AllocKeyedListIntRep(void)
 {
     keylIntObj_t *keylIntPtr;
 
@@ -458,9 +458,9 @@ AllocKeyedListIntRep ()
  *-----------------------------------------------------------------------------
  */
 static void
-FreeKeyedListData (keylIntPtr)
-    keylIntObj_t *keylIntPtr;
-{
+FreeKeyedListData(
+    keylIntObj_t *keylIntPtr
+) {
     int idx;
 
     for (idx = 0; idx < keylIntPtr->numEntries ; idx++) {
@@ -484,10 +484,10 @@ FreeKeyedListData (keylIntPtr)
  *-----------------------------------------------------------------------------
  */
 static void
-EnsureKeyedListSpace (keylIntPtr, newNumEntries)
-    keylIntObj_t *keylIntPtr;
-    int           newNumEntries;
-{
+EnsureKeyedListSpace(
+    keylIntObj_t *keylIntPtr,
+    int           newNumEntries
+) {
     KEYL_REP_ASSERT (keylIntPtr);
 
     if ((keylIntPtr->arraySize - keylIntPtr->numEntries) < newNumEntries) {
@@ -517,10 +517,10 @@ EnsureKeyedListSpace (keylIntPtr, newNumEntries)
  *-----------------------------------------------------------------------------
  */
 static void
-DeleteKeyedListEntry (keylIntPtr, entryIdx)
-    keylIntObj_t *keylIntPtr;
-    int           entryIdx;
-{
+DeleteKeyedListEntry (
+    keylIntObj_t *keylIntPtr,
+    int           entryIdx
+) {
     int idx;
 
     ckfree (keylIntPtr->entries [entryIdx].key);
@@ -549,16 +549,17 @@ DeleteKeyedListEntry (keylIntPtr, entryIdx)
  *-----------------------------------------------------------------------------
  */
 static int
-FindKeyedListEntry (keylIntPtr, key, keyLenPtr, nextSubKeyPtr)
-    keylIntObj_t *keylIntPtr;
-    const char   *key;
-    int          *keyLenPtr;
-    const char   **nextSubKeyPtr;
-{
-    char *keySeparPtr;
-    int keyLen, findIdx;
+FindKeyedListEntry(
+    keylIntObj_t *keylIntPtr,
+    const char   *key,
+    size_t       *keyLenPtr,
+    const char   **nextSubKeyPtr
+) {
+    const char *keySeparPtr;
+    size_t keyLen;
+    int findIdx;
 
-    keySeparPtr = strchr (key, '.');
+    keySeparPtr = strchr(key, '.');
     if (keySeparPtr != NULL) {
         keyLen = keySeparPtr - key;
     } else {
@@ -604,11 +605,11 @@ FindKeyedListEntry (keylIntPtr, key, keyLenPtr, nextSubKeyPtr)
  *-----------------------------------------------------------------------------
  */
 static int
-ObjToKeyedListEntry (interp, objPtr, entryPtr)
-    Tcl_Interp  *interp;
-    Tcl_Obj     *objPtr;
-    keylEntry_t *entryPtr;
-{
+ObjToKeyedListEntry(
+    Tcl_Interp  *interp,
+    Tcl_Obj     *objPtr,
+    keylEntry_t *entryPtr
+) {
     int objc;
     Tcl_Obj **objv;
     const char *key;
@@ -653,10 +654,10 @@ ObjToKeyedListEntry (interp, objPtr, entryPtr)
  *-----------------------------------------------------------------------------
  */
 static void
-FreeKeyedListInternalRep (keylPtr)
-    Tcl_Obj *keylPtr;
-{
-    FreeKeyedListData(keylPtr->internalRep.twoPtrValue.ptr1);
+FreeKeyedListInternalRep(
+    Tcl_Obj *keylPtr
+) {
+    FreeKeyedListData((keylIntObj_t *)keylPtr->internalRep.twoPtrValue.ptr1);
 }
 
 /*-----------------------------------------------------------------------------
@@ -669,11 +670,11 @@ FreeKeyedListInternalRep (keylPtr)
  *-----------------------------------------------------------------------------
  */
 static void
-DupKeyedListInternalRep (srcPtr, copyPtr)
-    Tcl_Obj *srcPtr;
-    Tcl_Obj *copyPtr;
-{
-    keylIntObj_t *srcIntPtr =
+DupKeyedListInternalRep(
+    Tcl_Obj *srcPtr,
+    Tcl_Obj *copyPtr
+) {
+    keylIntObj_t *srcIntPtr = (keylIntObj_t *)
         srcPtr->internalRep.twoPtrValue.ptr1;
     keylIntObj_t *copyIntPtr;
     int idx;
@@ -711,11 +712,11 @@ DupKeyedListInternalRep (srcPtr, copyPtr)
  *-----------------------------------------------------------------------------
  */
 void
-DupKeyedListInternalRepShared (srcPtr, copyPtr)
-    Tcl_Obj *srcPtr;
-    Tcl_Obj *copyPtr;
-{
-    keylIntObj_t *srcIntPtr =
+DupKeyedListInternalRepShared (
+    Tcl_Obj *srcPtr,
+    Tcl_Obj *copyPtr
+) {
+    keylIntObj_t *srcIntPtr = (keylIntObj_t *)
         srcPtr->internalRep.twoPtrValue.ptr1;
     keylIntObj_t *copyIntPtr;
     int idx;
@@ -753,10 +754,10 @@ DupKeyedListInternalRepShared (srcPtr, copyPtr)
  *-----------------------------------------------------------------------------
  */
 static int
-SetKeyedListFromAny (interp, objPtr)
-    Tcl_Interp *interp;
-    Tcl_Obj    *objPtr;
-{
+SetKeyedListFromAny(
+    Tcl_Interp *interp,
+    Tcl_Obj    *objPtr
+) {
     keylIntObj_t *keylIntPtr;
     int idx, objc;
     Tcl_Obj **objv;
@@ -799,15 +800,15 @@ SetKeyedListFromAny (interp, objPtr)
  *-----------------------------------------------------------------------------
  */
 static void
-UpdateStringOfKeyedList (keylPtr)
-    Tcl_Obj  *keylPtr;
-{
+UpdateStringOfKeyedList(
+    Tcl_Obj  *keylPtr
+) {
 #define UPDATE_STATIC_SIZE 32
     int idx;
     Tcl_Obj **listObjv, *entryObjv [2], *tmpListObj;
     Tcl_Obj *staticListObjv [UPDATE_STATIC_SIZE];
     char *listStr;
-    keylIntObj_t *keylIntPtr =
+    keylIntObj_t *keylIntPtr = (keylIntObj_t *)
         keylPtr->internalRep.twoPtrValue.ptr1;
 
     /*
@@ -852,7 +853,7 @@ UpdateStringOfKeyedList (keylPtr)
  *-----------------------------------------------------------------------------
  */
 Tcl_Obj *
-TclX_NewKeyedListObj ()
+TclX_NewKeyedListObj(void)
 {
     Tcl_Obj *keylPtr = Tcl_NewObj ();
     keylIntObj_t *keylIntPtr = AllocKeyedListIntRep ();
@@ -880,12 +881,12 @@ TclX_NewKeyedListObj ()
  *-----------------------------------------------------------------------------
  */
 int
-TclX_KeyedListGet (interp, keylPtr, key, valuePtrPtr)
-    Tcl_Interp *interp;
-    Tcl_Obj    *keylPtr;
-    const char *key;
-    Tcl_Obj   **valuePtrPtr;
-{
+TclX_KeyedListGet(
+    Tcl_Interp *interp,
+    Tcl_Obj    *keylPtr,
+    const char *key,
+    Tcl_Obj   **valuePtrPtr
+) {
     keylIntObj_t *keylIntPtr;
     const char *nextSubKey;
     int findIdx;
@@ -895,7 +896,7 @@ TclX_KeyedListGet (interp, keylPtr, key, valuePtrPtr)
             return TCL_ERROR;
         }
     }
-    keylIntPtr = keylPtr->internalRep.twoPtrValue.ptr1;
+    keylIntPtr = (keylIntObj_t *)keylPtr->internalRep.twoPtrValue.ptr1;
     KEYL_REP_ASSERT (keylIntPtr);
 
     findIdx = FindKeyedListEntry (keylIntPtr, key, NULL, &nextSubKey);
@@ -938,15 +939,16 @@ TclX_KeyedListGet (interp, keylPtr, key, valuePtrPtr)
  *-----------------------------------------------------------------------------
  */
 int
-TclX_KeyedListSet (interp, keylPtr, key, valuePtr)
-    Tcl_Interp *interp;
-    Tcl_Obj    *keylPtr;
-    const char *key;
-    Tcl_Obj    *valuePtr;
-{
+TclX_KeyedListSet(
+    Tcl_Interp *interp,
+    Tcl_Obj    *keylPtr,
+    const char *key,
+    Tcl_Obj    *valuePtr
+) {
     keylIntObj_t *keylIntPtr;
     const char *nextSubKey;
-    int findIdx, keyLen, status;
+    int findIdx, status;
+    size_t keyLen;
     Tcl_Obj *newKeylPtr;
 
     if (keylPtr->typePtr != &keyedListType) {
@@ -954,7 +956,7 @@ TclX_KeyedListSet (interp, keylPtr, key, valuePtr)
             return TCL_ERROR;
         }
     }
-    keylIntPtr = keylPtr->internalRep.twoPtrValue.ptr1;
+    keylIntPtr = (keylIntObj_t *)keylPtr->internalRep.twoPtrValue.ptr1;
     KEYL_REP_ASSERT (keylIntPtr);
 
     findIdx = FindKeyedListEntry (keylIntPtr, key,
@@ -1040,11 +1042,11 @@ TclX_KeyedListSet (interp, keylPtr, key, valuePtr)
  *-----------------------------------------------------------------------------
  */
 int
-TclX_KeyedListDelete (interp, keylPtr, key)
-    Tcl_Interp *interp;
-    Tcl_Obj    *keylPtr;
-    const char *key;
-{
+TclX_KeyedListDelete(
+    Tcl_Interp *interp,
+    Tcl_Obj    *keylPtr,
+    const char *key
+) {
     keylIntObj_t *keylIntPtr, *subKeylIntPtr;
     const char *nextSubKey;
     int findIdx, status;
@@ -1054,7 +1056,7 @@ TclX_KeyedListDelete (interp, keylPtr, key)
             return TCL_ERROR;
         }
     }
-    keylIntPtr = keylPtr->internalRep.twoPtrValue.ptr1;
+    keylIntPtr = (keylIntObj_t *)keylPtr->internalRep.twoPtrValue.ptr1;
 
     findIdx = FindKeyedListEntry (keylIntPtr, key, NULL, &nextSubKey);
 
@@ -1088,7 +1090,7 @@ TclX_KeyedListDelete (interp, keylPtr, key)
                                    keylIntPtr->entries [findIdx].valuePtr,
                                    nextSubKey);
     if (status == TCL_OK) {
-        subKeylIntPtr =
+        subKeylIntPtr = (keylIntObj_t *)
             keylIntPtr->entries [findIdx].valuePtr->internalRep.twoPtrValue.ptr1;
         if (subKeylIntPtr->numEntries == 0) {
             DeleteKeyedListEntry (keylIntPtr, findIdx);
@@ -1117,12 +1119,12 @@ TclX_KeyedListDelete (interp, keylPtr, key)
  *-----------------------------------------------------------------------------
  */
 int
-TclX_KeyedListGetKeys (interp, keylPtr, key, listObjPtrPtr)
-    Tcl_Interp *interp;
-    Tcl_Obj    *keylPtr;
-    const char *key;
-    Tcl_Obj   **listObjPtrPtr;
-{
+TclX_KeyedListGetKeys(
+    Tcl_Interp *interp,
+    Tcl_Obj    *keylPtr,
+    const char *key,
+    Tcl_Obj   **listObjPtrPtr
+) {
     keylIntObj_t *keylIntPtr;
     Tcl_Obj *nameObjPtr, *listObjPtr;
     const char *nextSubKey;
@@ -1133,7 +1135,7 @@ TclX_KeyedListGetKeys (interp, keylPtr, key, listObjPtrPtr)
             return TCL_ERROR;
         }
     }
-    keylIntPtr = keylPtr->internalRep.twoPtrValue.ptr1;
+    keylIntPtr = (keylIntObj_t *)keylPtr->internalRep.twoPtrValue.ptr1;
 
     /*
      * If key is not NULL or empty, then recurse down until we go past
@@ -1178,12 +1180,12 @@ TclX_KeyedListGetKeys (interp, keylPtr, key, listObjPtrPtr)
  *-----------------------------------------------------------------------------
  */
 static int
-Tcl_KeylgetObjCmd (clientData, interp, objc, objv)
-    ClientData   clientData;
-    Tcl_Interp  *interp;
-    int          objc;
-    Tcl_Obj     *const objv[];
-{
+Tcl_KeylgetObjCmd(
+    void        *clientData,
+    Tcl_Interp  *interp,
+    int          objc,
+    Tcl_Obj     *const objv[]
+) {
     Tcl_Obj *keylPtr, *valuePtr;
     const char *key;
     int status;
@@ -1259,15 +1261,16 @@ Tcl_KeylgetObjCmd (clientData, interp, objc, objv)
  *-----------------------------------------------------------------------------
  */
 static int
-Tcl_KeylsetObjCmd (clientData, interp, objc, objv)
-    ClientData   clientData;
-    Tcl_Interp  *interp;
-    int          objc;
-    Tcl_Obj     *const objv[];
-{
+Tcl_KeylsetObjCmd(
+    void        *dummy,
+    Tcl_Interp  *interp,
+    int          objc,
+    Tcl_Obj     *const objv[]
+) {
     Tcl_Obj *keylVarPtr, *newVarObj;
     const char *key;
     int idx;
+    (void)dummy;
 
     if ((objc < 4) || ((objc % 2) != 0)) {
         return TclX_WrongArgs (interp, objv [0],
@@ -1322,15 +1325,16 @@ Tcl_KeylsetObjCmd (clientData, interp, objc, objv)
  *----------------------------------------------------------------------------
  */
 static int
-Tcl_KeyldelObjCmd (clientData, interp, objc, objv)
-    ClientData   clientData;
-    Tcl_Interp  *interp;
-    int          objc;
-    Tcl_Obj     *const objv[];
-{
+Tcl_KeyldelObjCmd(
+    void        *dummy,
+    Tcl_Interp  *interp,
+    int          objc,
+    Tcl_Obj     *const objv[]
+) {
     Tcl_Obj *keylVarPtr, *keylPtr;
     const char *key;
     int idx, status;
+    (void)dummy;
 
     if (objc < 3) {
         return TclX_WrongArgs (interp, objv [0], "listvar key ?key ...?");
@@ -1384,15 +1388,16 @@ Tcl_KeyldelObjCmd (clientData, interp, objc, objv)
  *-----------------------------------------------------------------------------
  */
 static int
-Tcl_KeylkeysObjCmd (clientData, interp, objc, objv)
-    ClientData   clientData;
-    Tcl_Interp  *interp;
-    int          objc;
-    Tcl_Obj     *const objv[];
-{
+Tcl_KeylkeysObjCmd(
+    void        *dummy,
+    Tcl_Interp  *interp,
+    int          objc,
+    Tcl_Obj     *const objv[]
+) {
     Tcl_Obj *keylPtr, *listObjPtr;
     const char *key;
     int status;
+    (void)dummy;
 
     if ((objc < 2) || (objc > 3)) {
         return TclX_WrongArgs(interp, objv [0], "listvar ?key?");
@@ -1440,9 +1445,9 @@ Tcl_KeylkeysObjCmd (clientData, interp, objc, objv)
  *-----------------------------------------------------------------------------
  */
 void
-TclX_KeyedListInit (interp)
-    Tcl_Interp *interp;
-{
+TclX_KeyedListInit(
+    Tcl_Interp *interp
+) {
     Tcl_Obj *listobj;
     Tcl_RegisterObjType(&keyedListType);
 
@@ -1455,26 +1460,26 @@ TclX_KeyedListInit (interp)
     Tcl_CreateObjCommand (interp,
                           "keylget",
                           Tcl_KeylgetObjCmd,
-                          (ClientData) NULL,
-                          (Tcl_CmdDeleteProc*) NULL);
+                          NULL,
+                          NULL);
 
     Tcl_CreateObjCommand (interp,
                           "keylset",
                           Tcl_KeylsetObjCmd,
-                          (ClientData) NULL,
-                          (Tcl_CmdDeleteProc*) NULL);
+                          NULL,
+                          NULL);
 
     Tcl_CreateObjCommand (interp,
                           "keyldel",
                           Tcl_KeyldelObjCmd,
-                          (ClientData) NULL,
-                          (Tcl_CmdDeleteProc*) NULL);
+                          NULL,
+                          NULL);
 
     Tcl_CreateObjCommand (interp,
                           "keylkeys",
                           Tcl_KeylkeysObjCmd,
-                          (ClientData) NULL,
-                          (Tcl_CmdDeleteProc*) NULL);
+                          NULL,
+                          NULL);
     }
 }
 
