@@ -414,7 +414,7 @@ GetPsStore(const char *handle)
 {
     int i;
     const char *type = handle;
-    char *addr, *delimiter = strchr(handle, ':');
+    char *addr, *delimiter = (char *)strchr(handle, ':');
     PsStore *tmpPtr, *psPtr = NULL;
 
     /*
@@ -1446,6 +1446,7 @@ SvUnsetObjCmd(
     int ii;
     const char *arrayName;
     Array *arrayPtr;
+    (void)dummy;
 
     if (objc < 2) {
         Tcl_WrongNumArgs(interp, 1, objv, "array ?key ...?");
@@ -2033,6 +2034,7 @@ SvLockObjCmd(
     Tcl_Obj *scriptObj;
     Bucket *bucketPtr;
     Array *arrayPtr = NULL;
+    (void)dummy;
 
     /*
      * Syntax:
@@ -2100,12 +2102,13 @@ SvLockObjCmd(
  */
 static int
 SvHandlersObjCmd(
-             ClientData arg,                     /* Not used. */
+             ClientData dummy,                     /* Not used. */
              Tcl_Interp *interp,                 /* Current interpreter. */
              int objc,                           /* Number of arguments. */
              Tcl_Obj *const objv[])              /* Argument objects. */
 {
     PsStore *tmpPtr = NULL;
+    (void)dummy;
 
     /*
      * Syntax:
@@ -2340,7 +2343,7 @@ Sv_Init (
  */
 
 static void
-SvFinalize (ClientData clientData)
+SvFinalize (ClientData dummy)
 {
     int i;
     SvCmdInfo *cmdPtr;
@@ -2348,6 +2351,7 @@ SvFinalize (ClientData clientData)
 
     Tcl_HashEntry *hashPtr;
     Tcl_HashSearch search;
+    (void)dummy;
 
     /*
      * Decrement number of threads. Proceed only if I was the last one. The
